@@ -1,4 +1,5 @@
 from tpd_pete.pete import Pete
+import tpd_pete
 
 
 def main():
@@ -9,4 +10,5 @@ def main():
 
 
 if __name__ == "__main__":
+	print("TPD Deployment - Project Pete - v%s" % tpd_pete.VERSION)
 	main()
