@@ -3,24 +3,29 @@ import importlib.util
 
 from termcolor import cprint as print
 
-from .ideploymentaction import IDeploymentAction, EnvironmentEnum
+from .ideploymentaction import IDeploymentAction
 from ...tools.configuration import ConfigurationTool
-from ...ihook import IHook
+from ...ihook import DeploymentHook, IHook
 
 
 class HookDeployment(IDeploymentAction):
 	""" Deployment through Custom hooks
 	"""
+	@classmethod
+	def shouldExecute(cls):
+		""" Check if the Action should be deployed
+		"""
+		# Check if there are any custom hooks
+		return os.path.exists(".pete/hooks")
 
-	def start(self, **kwargs):
+	def start(self, environType, **kwargs):
 		""" Start the deployment
 		"""
 		# Get the configs
 		ConfigurationTool.readConfig()
 
-		# Check if it is the production environment
-		if kwargs['production'] is True:
-			self.environment = EnvironmentEnum.PRODUCTION
+		# Save the environment type
+		self.environment = environType
 
 		# Check if there is an hooks directory
 		if os.path.exists(".pete/hooks") is False:
@@ -49,9 +54,12 @@ class HookDeployment(IDeploymentAction):
 				print("There is no Hook class in %s" % fileName, "red")
 				return False
 
-			# Check if it is an IHook
-			if isinstance(hook, IHook) is False:
-				print("Hook %s is not a IHook subclass" % fileName, "red")
+			# Check if it is an DeploymentHook
+			if isinstance(hook, DeploymentHook) is False:
+				if isinstance(hook, IHook) is True:
+					continue
+
+				print("Hook %s is not a DeploymentHook subclass" % fileName, "red")
 				return False
 
 			# Run the execute
