@@ -4,6 +4,7 @@ import platform
 from . import VERSION
 from .actionmanager import ActionManager
 from .validator import Validator
+from .enums import EnvironmentType
 
 
 class Pete(object):
@@ -50,4 +51,9 @@ class Pete(object):
 
 		# Check if we used the deploy mode
 		if args.mode == "deploy":
-			return ActionManager.deploy(production=args.production)
+			# Check what environment type we are going to use
+			environType = EnvironmentType.DEVELOPMENT
+			if args.production is True:
+				environType = EnvironmentType.PRODUCTION
+
+			return ActionManager.deploy(environType)
