@@ -1,5 +1,4 @@
 import os
-import subprocess
 
 from .tools.configuration import ConfigurationTool
 
@@ -13,22 +12,17 @@ class Validator(object):
 		"""
 		pass
 
-	@classmethod
-	def hasAWSCli(cls):
-		""" Check if AWS cli is available
-		"""
-		try:
-			subprocess.check_call(["aws", "help"], shell=True)
-		except Exception:
-			return False
-		return True
-
 	@classmethod
 	def hasPeteSetup(cls):
 		""" Check if pete configure has been run
 		"""
+		# Check if the CI env var exists
+		if "PETE_CI" in os.environ:
+			# We are going to use the CI environment variables
+			return True
+
 		# Check the path
-		path = ConfigurationTool.getGlobalPath()
+		path = ConfigurationTool._getGlobalPath()
 
 		# Check if the path exists
 		if os.path.exists(path) is False:
@@ -40,7 +34,7 @@ class Validator(object):
 		""" Check if pete init has been run
 		"""
 		# Check the path
-		path = ConfigurationTool.getProjectPath()
+		path = ConfigurationTool._getProjectPath()
 
 		# Check if the path exists
 		if os.path.exists(path) is False:
